@@ -1,6 +1,5 @@
 #include "Functions.h"
 
-
 // The function checks if the given leaf node has ANY variables on which it can 
 // perform a valid split. It iterates through all the potential variables (stored 
 // in the `cutpoints` object) and checks if there is a range of possible cut 
@@ -39,11 +38,11 @@ bool Splittable(Tree& leaf_node, Cutpoints& cutpoints) {
 // Function retrieves the addresses (i.e., pointers to) of leaf nodes that can 
 // be split on. It collects all leaf nodes, checks if they are splittable, and 
 // removes those that can't be split.
-void CollectSplittableLeafs(Tree& tree, std::vector<Tree*>& leaf_vector, 
+void CollectSplittableLeaves(Tree& tree, std::vector<Tree*>& leaf_vector, 
                             Cutpoints& cutpoints) {
   
   // Collect all leaf nodes.
-  tree.CollectLeafs(leaf_vector);
+  tree.CollectLeaves(leaf_vector);
 
   // Iterate over the collected leaf nodes
   for (size_t i = 0; i < leaf_vector.size(); i++) {
@@ -106,7 +105,7 @@ double GrowProbability(Tree& tree, Cutpoints& cutpoints, TreePrior& tree_prior,
   // Probability of a birth move; to be returned
   double prob_birth; 
   std::vector<Tree*> leaf_nodes; // All the bottom nodes
-  tree.CollectLeafs(leaf_nodes);
+  tree.CollectLeaves(leaf_nodes);
   
   // Find all splittable bottom nodes
   for (size_t i = 0; i != leaf_nodes.size(); i++) {
@@ -264,10 +263,23 @@ double ProbNodeGrows(Tree& tree, Cutpoints& cutpoints, TreePrior& tree_prior) {
   }
 }
 
+//Helper functions to manage leaf_index_ during stats pass. Replaced old map-based approach.
+// Assigns 0..(leaves.size()-1) to each leaf’s leaf_index_.
+static inline void AssignLeafIndices(std::vector<Tree*>& leaves) {
+  for (size_t i = 0; i < leaves.size(); ++i) {
+    leaves[i]->SetLeafIndex(i);
+  }
+}
+
+// Clears the indices after we’re done (defensive).
+static inline void ClearLeafIndices(std::vector<Tree*>& leaves) {
+  for (Tree* leaf : leaves) leaf->ResetLeafIndex();
+}
 
 // Compute sufficient statistics for all bottom nodes in the tree. 
 // This method loops through all the data once, collecting the number of 
 // observations and the sum of residuals for each bottom node.
+/*
 void SufficientStatisticsAllLeaves(Tree& tree, Cutpoints& cutpoints, Data& data, 
                                    std::vector<Tree*>& bottom_nodes, 
                                    std::vector<size_t>& observation_count_vector, 
@@ -284,7 +296,7 @@ void SufficientStatisticsAllLeaves(Tree& tree, Cutpoints& cutpoints, Data& data,
 
   // Clear the vector of bottom nodes and collect them from the tree
   bottom_nodes.clear();
-  tree.CollectLeafs(bottom_nodes);
+  tree.CollectLeaves(bottom_nodes);
 
   // Resize the observation count and residual sum vectors to match the number of 
   // bottom nodes
@@ -315,6 +327,45 @@ void SufficientStatisticsAllLeaves(Tree& tree, Cutpoints& cutpoints, Data& data,
     residual_sum_vector[bottom_node_index] += data.GetResidual(i);
   }
 }
+*/
+
+void SufficientStatisticsAllLeaves(
+    Tree& tree,
+    Cutpoints& cutpoints,
+    Data& data,
+    std::vector<Tree*>& bottom_nodes,
+    std::vector<size_t>& observation_count_vector,
+    std::vector<double>& residual_sum_vector) {
+
+  bottom_nodes.clear();
+  tree.CollectLeaves(bottom_nodes);
+
+  // Assign dense indices to leaves once per pass
+  AssignLeafIndices(bottom_nodes);
+
+  const size_t L = bottom_nodes.size();
+  observation_count_vector.assign(L, 0);
+  residual_sum_vector.assign(L, 0.0);
+
+  // Fast raw pointers
+  const size_t N = data.GetN();
+  const size_t P = data.GetP();
+  double* Xrow = nullptr;
+  double* X = data.GetX();
+  double* resid = data.GetResidual();
+
+  // Main scan
+  for (size_t i = 0; i < N; ++i) {
+    Xrow = X + i * P;  // contiguous row
+    Tree* leaf = tree.FindLeaf(Xrow, cutpoints);  // iterative inline
+    const size_t idx = leaf->GetLeafIndex();      // O(1)
+    ++observation_count_vector[idx];
+    residual_sum_vector[idx] += resid[i];
+  }
+
+  // Defensive cleanup (cheap, keeps invariants simple)
+  ClearLeafIndices(bottom_nodes);
+}
 
 
 // New update function for scale mixture set-up
@@ -386,7 +437,6 @@ void FullUpdate(Tree& tree, Cutpoints& cutpoints, Data& data,
   }
 }
 
-
 // Draws a single mu (parameter) value from the posterior distribution
 double DrawMuOneLeave(size_t n, double sum_residuals, double prior_variance, 
                       double sigma, Random& random) {
@@ -534,9 +584,9 @@ double LogTreeRatio_GROW(size_t depth, const TreePrior& tree_prior) {
 }
 
 // Move ratio for the GROW move. Move ratio for the PRUNE move is the inverse.
-double LogMoveRatio(size_t number_of_nogs, size_t number_of_leafs, 
+double LogMoveRatio(size_t number_of_nogs, size_t number_of_leaves, 
                     double prune_prob, double grow_prob) {
 
   return std::log(prune_prob) - std::log(number_of_nogs) - 
-         (std::log(grow_prob) - std::log(number_of_leafs));
+         (std::log(grow_prob) - std::log(number_of_leaves));
 }
