@@ -6,6 +6,7 @@ test_that("ShrinkageTrees (horseshoe) works for continuous outcome", {
   y <- X[, 1] + rnorm(50)
   
   # Fit the model
+  set.seed(1)
   fit <- ShrinkageTrees(y = y, 
                         X_train = X,
                         X_test = X_test,
@@ -17,8 +18,7 @@ test_that("ShrinkageTrees (horseshoe) works for continuous outcome", {
                         N_post = 10,
                         N_burn = 5,
                         store_posterior_sample = TRUE,
-                        verbose = FALSE,
-                        seed = 1)
+                        verbose = FALSE)
   
   # Basic checks
   expect_type(fit, "list")
@@ -48,6 +48,7 @@ test_that("ShrinkageTrees (horseshoe) works for continuous outcome", {
   expect_true(sd(fit$test_predictions_sample) > 0)
   
   # Check reproducibility
+  set.seed(1)
   fit2 <- ShrinkageTrees(y = y, 
                          X_train = X,
                          X_test = X_test,
@@ -59,8 +60,7 @@ test_that("ShrinkageTrees (horseshoe) works for continuous outcome", {
                          N_post = 10,
                          N_burn = 5,
                          store_posterior_sample = TRUE,
-                         verbose = FALSE,
-                         seed = 1)
+                         verbose = FALSE)
   expect_equal(fit$train_predictions, fit2$train_predictions)
 })
 
@@ -73,6 +73,7 @@ test_that("ShrinkageTrees (horseshoe) works for binary outcome", {
   y <- ifelse(X[, 1] + rnorm(50) > 0, 1, 0)
   
   # Fit the model
+  set.seed(1)
   fit <- ShrinkageTrees(y = y, 
                         X_train = X,
                         X_test = X_test,
@@ -84,8 +85,7 @@ test_that("ShrinkageTrees (horseshoe) works for binary outcome", {
                         N_post = 10,
                         N_burn = 5,
                         store_posterior_sample = TRUE,
-                        verbose = FALSE,
-                        seed = 1)
+                        verbose = FALSE)
     
   # Basic checks
   expect_type(fit, "list")
@@ -118,6 +118,7 @@ test_that("ShrinkageTrees (horseshoe) works for binary outcome", {
   expect_true(sd(fit$test_predictions_sample) > 0)
   
   # Check reproducibility
+  set.seed(1)
   fit2 <- ShrinkageTrees(y = y, 
                          X_train = X,
                          X_test = X_test,
@@ -129,8 +130,7 @@ test_that("ShrinkageTrees (horseshoe) works for binary outcome", {
                          N_post = 10,
                          N_burn = 5,
                          store_posterior_sample = TRUE,
-                         verbose = FALSE,
-                         seed = 1)
+                         verbose = FALSE)
   expect_equal(fit$train_predictions, fit2$train_predictions)
 })
 
@@ -152,6 +152,7 @@ test_that("ShrinkageTrees (horseshoe) works for right-censored survival outcome"
   status <- as.numeric(true_time <= censor_time)
   
   # Fit the model
+  set.seed(1)
   fit <- ShrinkageTrees(y = time_obs, 
                         X_train = X,
                         X_test = X_test,
@@ -164,8 +165,7 @@ test_that("ShrinkageTrees (horseshoe) works for right-censored survival outcome"
                         N_post = 10,
                         N_burn = 5,
                         store_posterior_sample = TRUE,
-                        verbose = FALSE,
-                        seed = 1)
+                        verbose = FALSE)
   
   # Basic checks
   expect_type(fit, "list")
@@ -196,6 +196,7 @@ test_that("ShrinkageTrees (horseshoe) works for right-censored survival outcome"
   expect_true(sd(fit$test_predictions_sample) > 0)
   
   # Check reproducibility
+  set.seed(1)
   fit2 <- ShrinkageTrees(y = time_obs, 
                          X_train = X,
                          X_test = X_test,
@@ -208,8 +209,7 @@ test_that("ShrinkageTrees (horseshoe) works for right-censored survival outcome"
                          N_post = 10,
                          N_burn = 5,
                          store_posterior_sample = TRUE,
-                         verbose = FALSE,
-                         seed = 1)
+                         verbose = FALSE)
   expect_equal(fit$train_predictions, fit2$train_predictions)
 })
 
@@ -222,6 +222,7 @@ test_that("ShrinkageTrees (horseshoe_fw) works for continuous outcome", {
   y <- X[, 1] + rnorm(50)
   
   # Fit the model
+  set.seed(1)
   fit <- ShrinkageTrees(y = y, 
                         X_train = X,
                         X_test = X_test,
@@ -233,8 +234,7 @@ test_that("ShrinkageTrees (horseshoe_fw) works for continuous outcome", {
                         N_post = 10,
                         N_burn = 5,
                         store_posterior_sample = TRUE,
-                        verbose = FALSE,
-                        seed = 1)
+                        verbose = FALSE)
   
   # Basic checks
   expect_type(fit, "list")
@@ -269,6 +269,7 @@ test_that("ShrinkageTrees (horseshoe_fw) works for continuous outcome", {
   expect_true(all(fit$forestwide_shrinkage >= 0))
   
   # Check reproducibility
+  set.seed(1)
   fit2 <- ShrinkageTrees(y = y, 
                          X_train = X,
                          X_test = X_test,
@@ -280,8 +281,7 @@ test_that("ShrinkageTrees (horseshoe_fw) works for continuous outcome", {
                          N_post = 10,
                          N_burn = 5,
                          store_posterior_sample = TRUE,
-                         verbose = FALSE,
-                         seed = 1)
+                         verbose = FALSE)
   expect_equal(fit$train_predictions, fit2$train_predictions)
 })
 
@@ -294,6 +294,7 @@ test_that("ShrinkageTrees (horseshoe_EB) works for continuous outcome", {
   y <- X[, 1] + rnorm(50)
   
   # Fit the model
+  set.seed(1)
   fit <- ShrinkageTrees(y = y, 
                         X_train = X,
                         X_test = X_test,
@@ -305,8 +306,7 @@ test_that("ShrinkageTrees (horseshoe_EB) works for continuous outcome", {
                         N_post = 10,
                         N_burn = 5,
                         store_posterior_sample = TRUE,
-                        verbose = FALSE,
-                        seed = 1)
+                        verbose = FALSE)
   
   # Basic checks
   expect_type(fit, "list")
@@ -336,6 +336,7 @@ test_that("ShrinkageTrees (horseshoe_EB) works for continuous outcome", {
   expect_true(sd(fit$test_predictions_sample) > 0)
   
   # Check reproducibility
+  set.seed(1)
   fit2 <- ShrinkageTrees(y = y, 
                          X_train = X,
                          X_test = X_test,
@@ -347,8 +348,7 @@ test_that("ShrinkageTrees (horseshoe_EB) works for continuous outcome", {
                          N_post = 10,
                          N_burn = 5,
                          store_posterior_sample = TRUE,
-                         verbose = FALSE,
-                         seed = 1)
+                         verbose = FALSE)
   expect_equal(fit$train_predictions, fit2$train_predictions)
 })
 
@@ -361,6 +361,7 @@ test_that("ShrinkageTrees (half-cauchy) works for continuous outcome", {
   y <- X[, 1] + rnorm(50)
   
   # Fit the model
+  set.seed(1)
   fit <- ShrinkageTrees(y = y, 
                         X_train = X,
                         X_test = X_test,
@@ -371,8 +372,7 @@ test_that("ShrinkageTrees (half-cauchy) works for continuous outcome", {
                         N_post = 10,
                         N_burn = 5,
                         store_posterior_sample = TRUE,
-                        verbose = FALSE,
-                        seed = 1)
+                        verbose = FALSE)
   
   # Basic checks
   expect_type(fit, "list")
@@ -402,6 +402,7 @@ test_that("ShrinkageTrees (half-cauchy) works for continuous outcome", {
   expect_true(sd(fit$test_predictions_sample) > 0)
   
   # Check reproducibility
+  set.seed(1)
   fit2 <- ShrinkageTrees(y = y, 
                          X_train = X,
                          X_test = X_test,
@@ -412,8 +413,38 @@ test_that("ShrinkageTrees (half-cauchy) works for continuous outcome", {
                          N_post = 10,
                          N_burn = 5,
                          store_posterior_sample = TRUE,
-                         verbose = FALSE,
-                         seed = 1)
+                         verbose = FALSE)
   expect_equal(fit$train_predictions, fit2$train_predictions)
 })
 
+test_that("ShrinkageTrees errors on invalid outcome_type", {
+  X <- matrix(rnorm(20 * 2), ncol = 2)
+  y <- rnorm(20)
+  
+  expect_error(
+    ShrinkageTrees(
+      y = y,
+      X_train = X,
+      outcome_type = "invalid"
+    )
+  )
+})
+
+test_that("X_test defaults correctly", {
+  X <- matrix(rnorm(40), ncol = 2)
+  y <- rnorm(20)
+  
+  fit <- ShrinkageTrees(
+    y = y,
+    X_train = X,
+    outcome_type = "continuous",
+    number_of_trees = 5,
+    prior_type = "standard",
+    local_hp = 0.1,
+    N_post = 5,
+    N_burn = 2,
+    verbose = FALSE
+  )
+  
+  expect_length(fit$test_predictions, 1)
+})
\ No newline at end of file
